==> analysis-collector-1.3-sources.jar: hudson/plugins/analysis/collector/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.analysis.collector;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Compiler
     * 
     */
    public static String Analysis_Warnings_Warning_Origin() {
        return holder.format("Analysis.Warnings.Warning.Origin");
    }

    /**
     * Compiler
     * 
     */
    public static Localizable _Analysis_Warnings_Warning_Origin() {
        return new Localizable(holder, "Analysis.Warnings.Warning.Origin");
    }

    /**
     * Open Task
     * 
     */
    public static String Analysis_Tasks_Warning_Origin() {
        return holder.format("Analysis.Tasks.Warning.Origin");
    }

    /**
     * Open Task
     * 
     */
    public static Localizable _Analysis_Tasks_Warning_Origin() {
        return new Localizable(holder, "Analysis.Tasks.Warning.Origin");
    }

    /**
     * Warnings per project
     * 
     */
    public static String Portlet_WarningsTable() {
        return holder.format("Portlet.WarningsTable");
    }

    /**
     * Warnings per project
     * 
     */
    public static Localizable _Portlet_WarningsTable() {
        return new Localizable(holder, "Portlet.WarningsTable");
    }

    /**
     * Checkstyle
     * 
     */
    public static String Analysis_Checkstyle_Warning_Origin() {
        return holder.format("Analysis.Checkstyle.Warning.Origin");
    }

    /**
     * Checkstyle
     * 
     */
    public static Localizable _Analysis_Checkstyle_Warning_Origin() {
        return new Localizable(holder, "Analysis.Checkstyle.Warning.Origin");
    }

    /**
     * FindBugs
     * 
     */
    public static String Analysis_FindBugs_Warning_Origin() {
        return holder.format("Analysis.FindBugs.Warning.Origin");
    }

    /**
     * FindBugs
     * 
     */
    public static Localizable _Analysis_FindBugs_Warning_Origin() {
        return new Localizable(holder, "Analysis.FindBugs.Warning.Origin");
    }

    /**
     * PMD
     * 
     */
    public static String Analysis_PMD_Warning_Origin() {
        return holder.format("Analysis.PMD.Warning.Origin");
    }

    /**
     * PMD
     * 
     */
    public static Localizable _Analysis_PMD_Warning_Origin() {
        return new Localizable(holder, "Analysis.PMD.Warning.Origin");
    }

    /**
     * Analysis: one warning found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportSingleItem() {
        return holder.format("Analysis.ResultAction.HealthReportSingleItem");
    }

    /**
     * Analysis: one warning found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportSingleItem");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static String Analysis_Detail_header() {
        return holder.format("Analysis.Detail.header");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static Localizable _Analysis_Detail_header() {
        return new Localizable(holder, "Analysis.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String Analysis_Dry_Warning_Origin() {
        return holder.format("Analysis.Dry.Warning.Origin");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _Analysis_Dry_Warning_Origin() {
        return new Localizable(holder, "Analysis.Dry.Warning.Origin");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Analysis_ResultAction_OneFixedWarning() {
        return holder.format("Analysis.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneFixedWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Analysis_ResultAction_OneNewWarning() {
        return holder.format("Analysis.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneNewWarning");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * Analysis: {0} warnings found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Analysis.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Analysis: {0} warnings found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Warnings
     * 
     */
    public static String Analysis_FixedWarnings_Detail_header() {
        return holder.format("Analysis.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Warnings
     * 
     */
    public static Localizable _Analysis_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Analysis.FixedWarnings.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String Analysis_ResultAction_OneWarning() {
        return holder.format("Analysis.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneWarning");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static String Analysis_ProjectAction_Name() {
        return holder.format("Analysis.ProjectAction.Name");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static Localizable _Analysis_ProjectAction_Name() {
        return new Localizable(holder, "Analysis.ProjectAction.Name");
    }

    /**
     * Distribution of warnings by type
     * 
     */
    public static String Trend_type_analysis() {
        return holder.format("Trend.type.analysis");
    }

    /**
     * Distribution of warnings by type
     * 
     */
    public static Localizable _Trend_type_analysis() {
        return new Localizable(holder, "Trend.type.analysis");
    }

    /**
     * New Warnings
     * 
     */
    public static String Analysis_NewWarnings_Detail_header() {
        return holder.format("Analysis.NewWarnings.Detail.header");
    }

    /**
     * New Warnings
     * 
     */
    public static Localizable _Analysis_NewWarnings_Detail_header() {
        return new Localizable(holder, "Analysis.NewWarnings.Detail.header");
    }

    /**
     * Analysis: no warnings found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportNoItem() {
        return holder.format("Analysis.ResultAction.HealthReportNoItem");
    }

    /**
     * Analysis: no warnings found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportNoItem");
    }

    /**
     * Publish combined analysis results
     * 
     */
    public static String Analysis_Publisher_Name() {
        return holder.format("Analysis.Publisher.Name");
    }

    /**
     * Publish combined analysis results
     * 
     */
    public static Localizable _Analysis_Publisher_Name() {
        return new Localizable(holder, "Analysis.Publisher.Name");
    }

    /**
     * Static Analysis Trend
     * 
     */
    public static String Analysis_Trend_Name() {
        return holder.format("Analysis.Trend.Name");
    }

    /**
     * Static Analysis Trend
     * 
     */
    public static Localizable _Analysis_Trend_Name() {
        return new Localizable(holder, "Analysis.Trend.Name");
    }

}

==> analysis-collector-1.4-sources.jar: hudson/plugins/analysis/collector/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.analysis.collector;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Compiler
     * 
     */
    public static String Analysis_Warnings_Warning_Origin() {
        return holder.format("Analysis.Warnings.Warning.Origin");
    }

    /**
     * Compiler
     * 
     */
    public static Localizable _Analysis_Warnings_Warning_Origin() {
        return new Localizable(holder, "Analysis.Warnings.Warning.Origin");
    }

    /**
     * Warnings trend graph (type distribution)
     * 
     */
    public static String Portlet_WarningsOriginGraph() {
        return holder.format("Portlet.WarningsOriginGraph");
    }

    /**
     * Warnings trend graph (type distribution)
     * 
     */
    public static Localizable _Portlet_WarningsOriginGraph() {
        return new Localizable(holder, "Portlet.WarningsOriginGraph");
    }

    /**
     * Warnings trend graph (new vs. fixed)
     * 
     */
    public static String Portlet_WarningsNewVsFixedGraph() {
        return holder.format("Portlet.WarningsNewVsFixedGraph");
    }

    /**
     * Warnings trend graph (new vs. fixed)
     * 
     */
    public static Localizable _Portlet_WarningsNewVsFixedGraph() {
        return new Localizable(holder, "Portlet.WarningsNewVsFixedGraph");
    }

    /**
     * Open Task
     * 
     */
    public static String Analysis_Tasks_Warning_Origin() {
        return holder.format("Analysis.Tasks.Warning.Origin");
    }

    /**
     * Open Task
     * 
     */
    public static Localizable _Analysis_Tasks_Warning_Origin() {
        return new Localizable(holder, "Analysis.Tasks.Warning.Origin");
    }

    /**
     * Warnings per project
     * 
     */
    public static String Portlet_WarningsTable() {
        return holder.format("Portlet.WarningsTable");
    }

    /**
     * Warnings per project
     * 
     */
    public static Localizable _Portlet_WarningsTable() {
        return new Localizable(holder, "Portlet.WarningsTable");
    }

    /**
     * Checkstyle
     * 
     */
    public static String Analysis_Checkstyle_Warning_Origin() {
        return holder.format("Analysis.Checkstyle.Warning.Origin");
    }

    /**
     * Checkstyle
     * 
     */
    public static Localizable _Analysis_Checkstyle_Warning_Origin() {
        return new Localizable(holder, "Analysis.Checkstyle.Warning.Origin");
    }

    /**
     * FindBugs
     * 
     */
    public static String Analysis_FindBugs_Warning_Origin() {
        return holder.format("Analysis.FindBugs.Warning.Origin");
    }

    /**
     * FindBugs
     * 
     */
    public static Localizable _Analysis_FindBugs_Warning_Origin() {
        return new Localizable(holder, "Analysis.FindBugs.Warning.Origin");
    }

    /**
     * PMD
     * 
     */
    public static String Analysis_PMD_Warning_Origin() {
        return holder.format("Analysis.PMD.Warning.Origin");
    }

    /**
     * PMD
     * 
     */
    public static Localizable _Analysis_PMD_Warning_Origin() {
        return new Localizable(holder, "Analysis.PMD.Warning.Origin");
    }

    /**
     * Analysis: one warning found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportSingleItem() {
        return holder.format("Analysis.ResultAction.HealthReportSingleItem");
    }

    /**
     * Analysis: one warning found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportSingleItem");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static String Analysis_Detail_header() {
        return holder.format("Analysis.Detail.header");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static Localizable _Analysis_Detail_header() {
        return new Localizable(holder, "Analysis.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String Analysis_Dry_Warning_Origin() {
        return holder.format("Analysis.Dry.Warning.Origin");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _Analysis_Dry_Warning_Origin() {
        return new Localizable(holder, "Analysis.Dry.Warning.Origin");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Analysis_ResultAction_OneFixedWarning() {
        return holder.format("Analysis.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneFixedWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static String Analysis_ResultAction_OneNewWarning() {
        return holder.format("Analysis.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneNewWarning");
    }

    /**
     * Warnings trend graph (priority distribution)
     * 
     */
    public static String Portlet_WarningsPriorityGraph() {
        return holder.format("Portlet.WarningsPriorityGraph");
    }

    /**
     * Warnings trend graph (priority distribution)
     * 
     */
    public static Localizable _Portlet_WarningsPriorityGraph() {
        return new Localizable(holder, "Portlet.WarningsPriorityGraph");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * Analysis: {0} warnings found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Analysis.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Analysis: {0} warnings found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static String Analysis_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Analysis.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Analysis_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Analysis.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Fixed Warnings
     * 
     */
    public static String Analysis_FixedWarnings_Detail_header() {
        return holder.format("Analysis.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Warnings
     * 
     */
    public static Localizable _Analysis_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Analysis.FixedWarnings.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String Analysis_ResultAction_OneWarning() {
        return holder.format("Analysis.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Analysis_ResultAction_OneWarning() {
        return new Localizable(holder, "Analysis.ResultAction.OneWarning");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static String Analysis_ProjectAction_Name() {
        return holder.format("Analysis.ProjectAction.Name");
    }

    /**
     * Static Analysis Warnings
     * 
     */
    public static Localizable _Analysis_ProjectAction_Name() {
        return new Localizable(holder, "Analysis.ProjectAction.Name");
    }

    /**
     * Distribution of warnings by type
     * 
     */
    public static String Trend_type_analysis() {
        return holder.format("Trend.type.analysis");
    }

    /**
     * Distribution of warnings by type
     * 
     */
    public static Localizable _Trend_type_analysis() {
        return new Localizable(holder, "Trend.type.analysis");
    }

    /**
     * New Warnings
     * 
     */
    public static String Analysis_NewWarnings_Detail_header() {
        return holder.format("Analysis.NewWarnings.Detail.header");
    }

    /**
     * New Warnings
     * 
     */
    public static Localizable _Analysis_NewWarnings_Detail_header() {
        return new Localizable(holder, "Analysis.NewWarnings.Detail.header");
    }

    /**
     * Analysis: no warnings found.
     * 
     */
    public static String Analysis_ResultAction_HealthReportNoItem() {
        return holder.format("Analysis.ResultAction.HealthReportNoItem");
    }

    /**
     * Analysis: no warnings found.
     * 
     */
    public static Localizable _Analysis_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Analysis.ResultAction.HealthReportNoItem");
    }

    /**
     * Publish combined analysis results
     * 
     */
    public static String Analysis_Publisher_Name() {
        return holder.format("Analysis.Publisher.Name");
    }

    /**
     * Publish combined analysis results
     * 
     */
    public static Localizable _Analysis_Publisher_Name() {
        return new Localizable(holder, "Analysis.Publisher.Name");
    }

    /**
     * Static Analysis Trend
     * 
     */
    public static String Analysis_Trend_Name() {
        return holder.format("Analysis.Trend.Name");
    }

    /**
     * Static Analysis Trend
     * 
     */
    public static Localizable _Analysis_Trend_Name() {
        return new Localizable(holder, "Analysis.Trend.Name");
    }

}
